'use strict';

var implementation = require('../');
var test = require('tape');
var runTests = require('./tests');

test('as a constructor', function (t) {
	runTests(implementation, t);

	t.end();
});
